@@ -1,6 +1,6 @@
 //! System API and low level functions for it.
 use crate::export::Principal;
-use std::convert::TryFrom;
+use std::convert::{TryFrom, TryInto};
 
 pub mod call;
 pub mod stable;
@@ -23,6 +23,7 @@ pub fn trap(message: &str) -> ! {
     unreachable!()
 }
 
+/// Get current timestamp
 pub fn time() -> u64 {
     unsafe { ic0::time() as u64 }
 }
@@ -52,6 +53,14 @@ pub fn canister_balance() -> u64 {
     unsafe { ic0::canister_cycle_balance() as u64 }
 }
 
+/// Get the amount of funds available in the canister.
+pub fn canister_balance128() -> u128 {
+    let size = 16;
+    let mut buf = vec![0u8; size];
+    unsafe { ic0::canister_cycle_balance128(buf.as_mut_ptr() as i32) }
+    u128::from_le_bytes(buf.try_into().unwrap())
+}
+
 /// Sets the certified data of this canister.
 ///
 /// Canisters can store up to 32 bytes of data that is certified by
